==> ldap-account-manager_8.0.1.orig.tar.bz2: ldap-account-manager-8.0.1/templates/lib/extra/ckeditor/plugins/link/lang/he.js <==
﻿/*
Copyright (c) 2003-2021, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
*/
CKEDITOR.plugins.setLang( 'link', 'he', {
	acccessKey: 'מקש גישה',
	advanced: 'אפשרויות מתקדמות',
	advisoryContentType: 'Content Type מוצע',
	advisoryTitle: 'כותרת מוצעת',
	anchor: {
		toolbar: 'הוספת/עריכת נקודת עיגון',
		menu: 'מאפייני נקודת עיגון',
		title: 'מאפייני נקודת עיגון',
		name: 'שם לנקודת עיגון',
		errorName: 'יש להקליד שם לנקודת עיגון',
		remove: 'מחיקת נקודת עיגון'
	},
	anchorId: 'עפ"י זיהוי (ID) האלמנט',
	anchorName: 'עפ"י שם העוגן',
	charset: 'קידוד המשאב המקושר',
	cssClasses: 'גיליונות עיצוב קבוצות',
	download: 'Force Download', // MISSING
	displayText: 'Display Text', // MISSING
	emailAddress: 'כתובת הדוא"ל',
	emailBody: 'גוף ההודעה',
	emailSubject: 'נושא ההודעה',
	id: 'זיהוי (ID)',
	info: 'מידע על הקישור',
	langCode: 'קוד שפה',
	langDir: 'כיוון שפה',
	langDirLTR: 'שמאל לימין (LTR)',
	langDirRTL: 'ימין לשמאל (RTL)',
	menu: 'מאפייני קישור',
	name: 'שם',
	noAnchors: '(אין עוגנים זמינים בדף)',
	noEmail: 'יש להקליד את כתובת הדוא"ל',
	noUrl: 'יש להקליד את כתובת הקישור (URL)',
	noTel: 'Please type the phone number', // MISSING
	other: '<אחר>',
	phoneNumber: 'Phone number', // MISSING
	popupDependent: 'תלוי (Netscape)',
	popupFeatures: 'תכונות החלון הקופץ',
	popupFullScreen: 'מסך מלא (IE)',
	popupLeft: 'מיקום צד שמאל',
	popupLocationBar: 'סרגל כתובת',
	popupMenuBar: 'סרגל תפריט',
	popupResizable: 'שינוי גודל',
	popupScrollBars: 'ניתן לגלילה',
	popupStatusBar: 'סרגל חיווי',
	popupToolbar: 'סרגל הכלים',
	popupTop: 'מיקום צד עליון',
	rel: 'קשר גומלין',
	selectAnchor: 'בחירת עוגן',
	styles: 'סגנון',
	tabIndex: 'מספר טאב',
	target: 'מטרה',
	targetFrame: '<מסגרת>',
	targetFrameName: 'שם מסגרת היעד',
	targetPopup: '<חלון קופץ>',
	targetPopupName: 'שם החלון הקופץ',
	title: 'קישור',
	toAnchor: 'עוגן בעמוד זה',
	toEmail: 'דוא"ל',
	toUrl: 'כתובת (URL)',
	toPhone: 'Phone', // MISSING
	toolbar: 'הוספת/עריכת קישור',
	type: 'סוג קישור',
	unlink: 'הסרת הקישור',
	upload: 'העלאה'
} );

==> ldap-account-manager_8.5.orig.tar.bz2: ldap-account-manager-8.5/templates/lib/extra/ckeditor/plugins/link/lang/he.js <==
﻿/*
Copyright (c) 2003-2023, CKSource Holding sp. z o.o. All rights reserved.
CKEditor 4 LTS ("Long Term Support") is available under the terms of the Extended Support Model.
*/
CKEDITOR.plugins.setLang( 'link', 'he', {
	acccessKey: 'מקש גישה',
	advanced: 'אפשרויות מתקדמות',
	advisoryContentType: 'Content Type מוצע',
	advisoryTitle: 'כותרת מוצעת',
	anchor: {
		toolbar: 'הוספת/עריכת נקודת עיגון',
		menu: 'מאפייני נקודת עיגון',
		title: 'מאפייני נקודת עיגון',
		name: 'שם לנקודת עיגון',
		errorName: 'יש להקליד שם לנקודת עיגון',
		errorWhitespace: 'Anchor name cannot contain space characters', // MISSING
		remove: 'מחיקת נקודת עיגון'
	},
	anchorId: 'עפ"י זיהוי (ID) האלמנט',
	anchorName: 'עפ"י שם העוגן',
	charset: 'קידוד המשאב המקושר',
	cssClasses: 'גיליונות עיצוב קבוצות',
	download: 'Force Download', // MISSING
	displayText: 'Display Text', // MISSING
	emailAddress: 'כתובת הדוא"ל',
	emailBody: 'גוף ההודעה',
	emailSubject: 'נושא ההודעה',
	id: 'זיהוי (ID)',
	info: 'מידע על הקישור',
	langCode: 'קוד שפה',
	langDir: 'כיוון שפה',
	langDirLTR: 'שמאל לימין (LTR)',
	langDirRTL: 'ימין לשמאל (RTL)',
	menu: 'מאפייני קישור',
	name: 'שם',
	noAnchors: '(אין עוגנים זמינים בדף)',
	noEmail: 'יש להקליד את כתובת הדוא"ל',
	noUrl: 'יש להקליד את כתובת הקישור (URL)',
	noTel: 'Please type the phone number', // MISSING
	other: '<אחר>',
	phoneNumber: 'Phone number', // MISSING
	popupDependent: 'תלוי (Netscape)',
	popupFeatures: 'תכונות החלון הקופץ',
	popupFullScreen: 'מסך מלא (IE)',
	popupLeft: 'מיקום צד שמאל',
	popupLocationBar: 'סרגל כתובת',
	popupMenuBar: 'סרגל תפריט',
	popupResizable: 'שינוי גודל',
	popupScrollBars: 'ניתן לגלילה',
	popupStatusBar: 'סרגל חיווי',
	popupToolbar: 'סרגל הכלים',
	popupTop: 'מיקום צד עליון',
	rel: 'קשר גומלין',
	selectAnchor: 'בחירת עוגן',
	styles: 'סגנון',
	tabIndex: 'מספר טאב',
	target: 'מטרה',
	targetFrame: '<מסגרת>',
	targetFrameName: 'שם מסגרת היעד',
	targetPopup: '<חלון קופץ>',
	targetPopupName: 'שם החלון הקופץ',
	title: 'קישור',
	toAnchor: 'עוגן בעמוד זה',
	toEmail: 'דוא"ל',
	toUrl: 'כתובת (URL)',
	toPhone: 'Phone', // MISSING
	toolbar: 'הוספת/עריכת קישור',
	type: 'סוג קישור',
	unlink: 'הסרת הקישור',
	upload: 'העלאה'
} );
